<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function reviewpro_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Container layouts
	$container = reviewpro_mod( PREFIX . 'container-layouts' );
	$classes[] = 'container-' . $container;

	// Default layout
	if ( !is_category() && !is_singular() ) {
		$classes[] = 'default-list-style';
	}

	// Single post featured image
	$style = get_post_meta( get_the_ID(), 'tj_featured_image_style', true );
	if ( $style === 'big_style' ) {
		$classes[] = 'featured-image-big';
	}

	return $classes;
}
add_filter( 'body_class', 'reviewpro_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function reviewpro_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	return $classes;
}
add_filter( 'post_class', 'reviewpro_post_classes' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function reviewpro_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'reviewpro_excerpt_more' );

/**
 * Control excerpt length.
 *
 * @since  1.0.0
 */
function reviewpro_excerpt_length( $length ) {

	$num = 30;

	// Change the excerpt length on full width layout
	if ( in_array( get_theme_mod( 'theme_layout' ), array( '1c' ) ) ) {
		$num = 50;
	}

	return $num;
}
add_filter( 'excerpt_length', 'reviewpro_excerpt_length', 999 );

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 *
 * @since 1.0.0
 */
function reviewpro_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );

	// bbPress
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );
}
add_action( 'init', 'reviewpro_remove_theme_layout_metabox', 11 );

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 *
 * @since  1.0.0
 */
function reviewpro_page_sidebar_plugin() {
	if ( class_exists( 'Simple_Page_Sidebars' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'reviewpro_page_sidebar_plugin' );

/**
 * Register custom contact info fields.
 *
 * @since  1.0.0
 * @param  array $contactmethods
 * @return array
 */
function reviewpro_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'reviewpro' );
	$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'reviewpro' );
	$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'reviewpro' );
	$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'reviewpro' );
	$contactmethods['linkedin']    = esc_html__( 'Linkedin URL', 'reviewpro' );
	$contactmethods['pinterest']   = esc_html__( 'Pinterest URL', 'reviewpro' );

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'reviewpro_contact_info_fields' );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function reviewpro_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = sprintf( esc_html__( 'Tag: %s', 'reviewpro' ), single_tag_title( '', false ) );
	} elseif ( is_author() ) {
		$title = sprintf( esc_html__( 'Posts by %s', 'reviewpro' ), get_the_author() );
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'reviewpro_extend_archive_title' );

/**
 * Customize tag cloud widget
 *
 * @since  1.0.0
 */
function reviewpro_customize_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'reviewpro_customize_tag_cloud' );

/**
 * Modifies the theme layout.
 *
 * @since  1.0.0
 */
function reviewpro_mod_theme_layout( $layout ) {

	// Change the layout to Full Width on Attachment page.
	if ( is_attachment() && wp_attachment_is_image() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	// Change the layout to Full Width on teams page template.
	if ( is_page_template( 'page-templates/teams.php' ) ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'reviewpro_mod_theme_layout', 15 );

/**
 * Custom <header> attributes
 */
function reviewpro_attr_header( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_header',  'reviewpro_attr_header' );

/**
 * Custom <footer> attributes
 */
function reviewpro_attr_footer( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_footer', 'reviewpro_attr_footer' );

/**
 * Custom <main> attributes
 */
function reviewpro_attr_main( $attr ) {
	$attr['class'] = 'site-main';
	unset( $attr['id'] );
	unset( $attr['role'] );

	if ( isset( $attr['itemprop'] ) ) {
		$attr['itemtype']  = 'http://schema.org/WebPageElement';
		$attr['itemscope'] = 'itemscope';
	}

	return $attr;
}
add_filter( 'hybrid_attr_content', 'reviewpro_attr_main' );

/**
 * Custom sidebar attributes
 */
function reviewpro_attr_sidebar( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_sidebar', 'reviewpro_attr_sidebar' );

/**
 * Custom <nav> attributes
 */
function reviewpro_attr_menu( $attr ) {
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_menu', 'reviewpro_attr_menu' );

/**
 * Custom site-title
 */
function reviewpro_attr_site_title( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_site-title', 'reviewpro_attr_site_title' );

/**
 * Custom site-description
 */
function reviewpro_attr_site_description( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_site-description', 'reviewpro_attr_site_description' );

/**
 * Custom post <article> attributes
 */
function reviewpro_attr_post( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_post', 'reviewpro_attr_post' );

/**
 * Custom entry-title
 */
function reviewpro_attr_entry_title( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-title', 'reviewpro_attr_entry_title' );

/**
 * Custom entry-author
 */
function reviewpro_attr_entry_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-author', 'reviewpro_attr_entry_author' );

/**
 * Custom entry-published
 */
function reviewpro_attr_entry_published( $attr ) {
	unset( $attr['class'] );
	unset( $attr['content'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-published', 'reviewpro_attr_entry_published' );

/**
 * Custom entry-content
 */
function reviewpro_attr_entry_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-content', 'reviewpro_attr_entry_content' );

/**
 * Custom entry-summary
 */
function reviewpro_attr_entry_summary( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-summary', 'reviewpro_attr_entry_summary' );

/**
 * Custom entry-terms
 */
function reviewpro_attr_entry_terms( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-terms', 'reviewpro_attr_entry_terms' );

/**
 * Comments
 */
function reviewpro_attr_comment( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment', 'reviewpro_attr_comment' );

/**
 * Custom comment-author
 */
function reviewpro_attr_comment_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-author', 'reviewpro_attr_comment_author' );

/**
 * Custom comment-published
 */
function reviewpro_attr_comment_published( $attr ) {
	unset( $attr['datetime'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-published', 'reviewpro_attr_comment_published' );

/**
 * Custom comment-permalink
 */
function reviewpro_attr_comment_permalink( $attr ) {
	unset( $attr['href'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-permalink', 'reviewpro_attr_comment_permalink' );

/**
 * Custom comment-content
 */
function reviewpro_attr_comment_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-content', 'reviewpro_attr_comment_content' );

/**
 * Remove role="navigation" from the_posts_pagination()
 */
function reviewpro_navigation_markup_template( $template ) {
	return str_replace( ' role="navigation"', '', $template );
}
add_filter( 'navigation_markup_template', 'reviewpro_navigation_markup_template' );
