<?php
/**
 * Recent Posts with Thumbnail widget.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class ReviewPro_Recent_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget_recent_entries_thumbnail posts-thumbnail-widget',
			'description' => esc_html__( 'Display recent posts with thumbnails.', 'reviewpro' ),
			'customize_selective_refresh' => true
		);

		// Create the widget.
		parent::__construct(
			'reviewpro-recent-posts',                                     // $this->id_base
			esc_html__( '&raquo; Recent Posts Thumbnails', 'reviewpro' ), // $this->name
			$widget_options                                               // $this->widget_options
		);

		$this->alt_option_name = 'widget_recent_entries_thumbnail';

	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title     = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';
		$number    = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;
		$style     = isset( $instance['style'] ) ? $instance['style'] : 'default';

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $title, $instance, $this->id_base ) . $args['after_title'];
		}

			// Posts query arguments.
			$query = array(
				'post_type'      => 'post',
				'posts_per_page' => $number
			);

			// The post query
			$recent = new WP_Query( $query );

			// Set image size
			$size = 'thumbnail';
			if ( $style !== 'default' ) {
				$size = 'post-thumbnail';
			}

			if ( $recent->have_posts() ) : ?>
				<ul class="<?php echo $style . '-style'; ?>">

					<?php while ( $recent->have_posts() ) : $recent->the_post(); ?>

						<li>
							<?php if ( $style !== 'default' ) : ?>
								<?php reviewpro_first_category(); ?>
							<?php endif; ?>
							<?php if ( has_post_thumbnail() ) : ?>
								<a class="thumbnail-link" href="<?php the_permalink(); ?>" rel="bookmark">
									<?php the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
									<span class="img-overlay"></span>
								</a>
							<?php endif; ?>
							<div class="post-detail">
								<a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
								<?php if ( $show_date ) : ?>
									<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() ); ?></time>
								<?php endif; ?>
							</div>
						</li>

					<?php endwhile; ?>

				</ul>
			<?php
			endif;

			// Reset the query.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance['title']     = sanitize_text_field( $new_instance['title'] );
		$instance['number']    = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		$instance['style']     = isset( $new_instance['style'] ) ? esc_attr( $new_instance['style'] ) : 'default';

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : esc_html__( 'Recent Posts', 'reviewpro' );
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		$style     = isset( $instance['style'] ) ? esc_attr( $instance['style'] ) : 'default';
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>">
				<?php esc_html_e( 'Number of posts to show', 'reviewpro' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="0" value="<?php echo $number; ?>" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'show_date' ); ?>">
				<?php esc_html_e( 'Display post date?', 'reviewpro' ); ?>
			</label>
		</p>

		<p>
			<label for=""><?php esc_html_e( 'Style type', 'reviewpro' ); ?></label>
			<ul>
				<li>
					<input class="radio" type="radio" value="default" <?php checked( $style, 'default' ); ?> id="<?php echo $this->get_field_id( 'style' ); ?>-default" name="<?php echo $this->get_field_name( 'style' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'style' ); ?>-default">
						<?php esc_html_e( 'Default', 'reviewpro' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="big-thumbnail" <?php checked( $style, 'big-thumbnail' ); ?> id="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail" name="<?php echo $this->get_field_name( 'style' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail">
						<?php esc_html_e( 'Big Thumbnail', 'reviewpro' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="big-thumbnail-overlay" <?php checked( $style, 'big-thumbnail-overlay' ); ?> id="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail-overlay" name="<?php echo $this->get_field_name( 'style' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail-overlay">
						<?php esc_html_e( 'Big Thumbnail Overlay', 'reviewpro' ); ?>
					</label>
				</li>
			</ul>
		</p>

	<?php

	}

}
